import org.junit.Test;
import static org.junit.Assert.*;

/** Performs a test of the IntList class
 *  @author Josh Hug
 */

public class IntListTest {

	/** Tests the incrList method */

	@Test
	public void testIncrList() {
		IntList x = IntList.list(0, 1, 2);
		IntList xp2 = IntList.list(2, 3, 4);
		IntList actual = IntList.incrList(x, 2);
		assertEquals(xp2, actual);

		IntList og = IntList.list(0, 1, 2);
		assertEquals(og, x);
	}

	/** Tests the incrListIterative method */

	@Test
	public void incrListIterative() {
		IntList x = IntList.list(0, 1, 2);
		IntList xp2 = IntList.list(2, 3, 4);
		IntList actual = IntList.incrListIterative(x, 2);
		assertEquals(xp2, actual);

		IntList og = IntList.list(0, 1, 2);
		assertEquals(og, x);
	}

	/** Tests the dincrList method */

	@Test
	public void testDincrList() {
		IntList x = IntList.list(0, 1, 2);
		IntList xp2 = IntList.list(2, 3, 4);
		IntList actual = IntList.dincrList(x, 2);
		assertEquals(xp2, actual);

		IntList og = IntList.list(0, 1, 2);
		assertNotEquals(og, x);
	}

	/** Tests the dincrListIterative method */

	@Test
	public void testDincrListIterative() {
		IntList x = IntList.list(0, 1, 2);
		IntList xp2 = IntList.list(2, 3, 4);
		IntList actual = IntList.dincrListIterative(x, 2);
		assertEquals(xp2, actual);

		IntList og = IntList.list(0, 1, 2);
		assertNotEquals(og, x);
	}

	/** Tests the non-destructive removeAll method */

	@Test
	public void testRemoveAll() {
		IntList x = IntList.list(4, 1, 2, 3);
		IntList expected = IntList.list(4, 1, 3);
		assertEquals(expected, IntList.removeAll(x, 2));

		x = IntList.list(2, 2, 1, 1, 2, 5, 2);
		expected = IntList.list(1, 1, 5);
		assertEquals(expected, IntList.removeAll(x, 2));
	}

	/** Tests the non-destructive removeAll method */

	@Test
	public void testRemoveAllIterative() {
		IntList x = IntList.list(4, 1, 2, 3);
		IntList expected = IntList.list(4, 1, 3);
		assertEquals(expected, IntList.removeAllIterative(x, 2));

		x = IntList.list(2, 2, 1, 1, 2, 5, 2);
		expected = IntList.list(1, 1, 5);
		assertEquals(expected, IntList.removeAllIterative(x, 2));
	}


	/* Tests destructive recursive removeAll */

	@Test
	public void testDremoveAll() {
		IntList x = IntList.list(4, 1, 2, 3);
		IntList expected = IntList.list(4, 1, 3);
		assertEquals(expected, IntList.dremoveAll(x, 2));

		x = IntList.list(2, 2, 1, 1, 2, 5, 2);
		expected = IntList.list(1, 1, 5);
		assertEquals(expected, IntList.dremoveAll(x, 2));

	}
	/* Tests destructive iterative removeAll */


	@Test
	public void testDremoveAllIterative() {
		IntList x = IntList.list(4, 1, 2, 3);
		IntList expected = IntList.list(4, 1, 3);
		assertEquals(expected, IntList.dremoveAllIterativeRefactored(x, 2));

		x = IntList.list(2, 2, 1, 1, 2, 5, 2);
		expected = IntList.list(1, 1, 5);
		assertEquals(expected, IntList.dremoveAllIterativeRefactored(x, 2));

	}


	/** Runs all IntList tests
	 */

	public static void main(String[] args) {
		ucb.junit.textui.runClasses(IntListTest.class);
	}
}		